@@ -6,6 +6,7 @@
 #include <librssguard/services/abstract/gui/formfeeddetails.h>
 
 class StandardFeedDetails;
+class StandardFeedExpDetails;
 class StandardServiceRoot;
 class AuthenticationDetails;
 class StandardFeed;
@@ -31,6 +32,7 @@ class FormStandardFeedDetails : public FormFeedDetails {
 
   private:
     StandardFeedDetails* m_standardFeedDetails;
+    StandardFeedExpDetails* m_standardFeedExpDetails;
     AuthenticationDetails* m_authDetails;
     RootItem* m_parentToSelect;
     QString m_urlToProcess;
