@@ -42,7 +42,7 @@ TextBrowserViewer::TextBrowserViewer(QWidget* parent)
   setDocument(m_document.data());
 
   m_resourceDownloader->moveToThread(m_resourceDownloaderThread);
-  m_resourceDownloaderThread->start();
+  m_resourceDownloaderThread->start(QThread::Priority::LowPriority);
 
   connect(this, &TextBrowserViewer::reloadDocument, this, [this]() {
     const auto scr = verticalScrollBarPosition();
@@ -418,9 +418,10 @@ void TextBrowserViewer::onAnchorClicked(const QUrl& url) {
 
 void TextBrowserViewer::setHtml(const QString& html, const QUrl& base_url) {
   if (m_resourcesEnabled) {
+    // NOTE: This regex is problematic as it does not work for ALL
+    // HTMLs, maybe use XML parsing to extract what we need?
     static QRegularExpression img_tag_rgx("\\<img[^\\>]*src\\s*=\\s*[\"\']([^\"\']*)[\"\'][^\\>]*\\>",
-                                          QRegularExpression::PatternOption::CaseInsensitiveOption |
-                                            QRegularExpression::PatternOption::InvertedGreedinessOption);
+                                          QRegularExpression::PatternOption::CaseInsensitiveOption);
     QRegularExpressionMatchIterator i = img_tag_rgx.globalMatch(html);
     QList<QUrl> found_resources;
 
@@ -603,8 +604,7 @@ PreparedHtml TextBrowserViewer::prepareLegacyHtmlForMessage(const QList<Message>
                             : message.m_contents;
 
     static QRegularExpression img_tag_rgx(QSL("\\<img[^\\>]*src\\s*=\\s*[\"\']([^\"\']*)[\"\'][^\\>]*\\>"),
-                                          QRegularExpression::PatternOption::CaseInsensitiveOption |
-                                            QRegularExpression::PatternOption::InvertedGreedinessOption);
+                                          QRegularExpression::PatternOption::CaseInsensitiveOption);
 
     // Extract all images links from article to be appended to end of article.
     QRegularExpressionMatchIterator i = img_tag_rgx.globalMatch(html.m_html);
