@@ -153,9 +153,8 @@ Application::Application(const QString& id, int& argc, char** argv, const QStrin
   m_database = new DatabaseFactory(this);
   m_downloadManager = nullptr;
   m_notifications = new NotificationFactory(this);
-  m_toastNotifications = settings()->value(GROUP(GUI), SETTING(GUI::UseToastNotifications)).toBool()
-                           ? new ToastNotificationsManager(this)
-                           : nullptr;
+  m_toastNotifications =
+    (!isWayland() && m_notifications->useToastNotifications()) ? new ToastNotificationsManager(this) : nullptr;
   m_shouldRestart = false;
 
 #if defined(Q_OS_WIN)
@@ -222,7 +221,13 @@ Application::Application(const QString& id, int& argc, char** argv, const QStrin
   }
 #endif
 
-  m_webFactory->setCustomUserAgent(custom_ua);
+  if (!custom_ua.isEmpty()) {
+    m_webFactory->setCustomUserAgent(custom_ua);
+  }
+  else {
+    custom_ua = qApp->settings()->value(GROUP(Network), SETTING(Network::CustomUserAgent)).toString();
+    m_webFactory->setCustomUserAgent(custom_ua);
+  }
 
 #if defined(NO_LITE)
   m_webFactory->urlIinterceptor()->load();
@@ -295,6 +300,7 @@ Application::Application(const QString& id, int& argc, char** argv, const QStrin
 
   setupWorkHorsePool();
 
+  qDebugNN << LOGSEC_CORE << "Platform:" << QUOTE_W_SPACE_DOT(QGuiApplication::platformName());
   qDebugNN << LOGSEC_CORE << "SQLite version:" << QUOTE_W_SPACE_DOT(SQLITE_VERSION);
   qDebugNN << LOGSEC_CORE << "OpenSSL version:" << QUOTE_W_SPACE_DOT(QSslSocket::sslLibraryVersionString());
   qDebugNN << LOGSEC_CORE << "OpenSSL supported:" << QUOTE_W_SPACE_DOT(QSslSocket::supportsSsl());
@@ -861,6 +867,10 @@ bool Application::usingLite() const {
 #endif
 }
 
+bool Application::isWayland() const {
+  return QGuiApplication::platformName() == QSL("wayland");
+}
+
 void Application::onCommitData(QSessionManager& manager) {
   qDebugNN << LOGSEC_CORE << "OS asked application to commit its data.";
 
@@ -1151,6 +1161,12 @@ void Application::setupWorkHorsePool() {
     m_workHorsePool->setMaxThreadCount((std::min)(MAX_THREADPOOL_THREADS, 2 * ideal_th_count));
   }
 
+#if QT_VERSION >= 0x060200 // Qt >= 6.2.0
+  // Avoid competing with interactive processes/threads by running the
+  // worker pool at a very low priority
+  m_workHorsePool->setThreadPriority(QThread::Priority::LowestPriority);
+#endif
+
   // NOTE: Do not expire threads so that their IDs are not reused.
   // This fixes cross-thread QSqlDatabase access.
   m_workHorsePool->setExpiryTimeout(-1);
@@ -1358,7 +1374,8 @@ void Application::fillCmdArgumentsParser(QCommandLineParser& parser) {
                                   QSL("style-name"));
 
   QCommandLineOption custom_ua({QSL(CLI_USERAGENT_SHORT), QSL(CLI_USERAGENT_LONG)},
-                               QSL("User custom User-Agent HTTP header for all network requests."),
+                               QSL("User custom User-Agent HTTP header for all network requests. This option "
+                                   "takes precedence over User-Agent set via application settings."),
                                QSL("user-agent"));
   QCommandLineOption
     adblock_port({QSL(CLI_ADBLOCKPORT_SHORT), QSL(CLI_ADBLOCKPORT_LONG)},
@@ -1387,7 +1404,7 @@ void Application::onNodeJsPackageUpdateError(const QObject* sndr,
                                              const QString& error) {
   Q_UNUSED(sndr)
   qApp->showGuiMessage(Notification::Event::NodePackageFailedToUpdate,
-                       {tr("Node.js"),
+                       {QSL("Node.js"),
                         tr("Packages were NOT updated because of error: %2. Affected packages:\n%1")
                           .arg(NodeJs::packagesToString(pkgs), error),
                         QSystemTrayIcon::MessageIcon::Critical});
